@@ -49,7 +49,7 @@ class MercuryGraphQLClient(MercuryHTTPClient):
                     await event.wait()
 
                 if action.hooks.before:
-                    action = await action.hooks.before(action, response)
+                    action = await action.hooks.before.call(action, response)
                     action.setup()
 
                 response.start = time.monotonic()
@@ -166,13 +166,13 @@ class MercuryGraphQLClient(MercuryHTTPClient):
                 self.pool.connections.append(connection)
 
                 if action.hooks.after:
-                    action = await action.hooks.after(action, response)
+                    action = await action.hooks.after.call(action, response)
                     action.setup()
 
                 if action.hooks.notify:
                     await asyncio.gather(*[
                         asyncio.create_task(
-                            channel(response, action.hooks.listeners)
+                            channel.call(response, action.hooks.listeners)
                         ) for channel in action.hooks.channels
                     ])
 
