@@ -137,14 +137,14 @@ class MercuryHTTPClient:
             connection = self.pool.connections.pop()
             
             try:
-                
+
                 if action.hooks.listen:
                     event = asyncio.Event()
                     action.hooks.channel_events.append(event)
                     await event.wait()
 
                 if action.hooks.before:
-                    action = await action.hooks.before(action, response)
+                    action = await action.hooks.before.call(action, response)
                     action.setup()
 
                 response.start = time.monotonic()
@@ -269,13 +269,13 @@ class MercuryHTTPClient:
                 self.pool.connections.append(connection)
 
                 if action.hooks.after:
-                    action = await action.hooks.after(action, response)
+                    action = await action.hooks.after.call(action, response)
                     action.setup()
 
                 if action.hooks.notify:
                     await asyncio.gather(*[
                         asyncio.create_task(
-                            channel(response, action.hooks.listeners)
+                            channel.call(response, action.hooks.listeners)
                         ) for channel in action.hooks.channels
                     ])
 
