@@ -15,7 +15,8 @@ class Task(BaseAction):
         'hooks',
         'type',
         'source',
-        'execute'
+        'execute',
+        'event'
     )
 
     def __init__(
@@ -36,6 +37,7 @@ class Task(BaseAction):
         self.source = source
         self.execute = task_action
         self.hooks: Hooks[Task] = Hooks()
+        self.event = None
 
     def to_serializable(self):
 
