@@ -1,4 +1,4 @@
-from typing import Any, Callable, Awaitable
+from typing import Any, Callable, Awaitable, Optional
 from hedra.core.graphs.simple_context import SimpleContext
 from hedra.core.graphs.hooks.hook_types.hook_type import HookType
 from .hook import Hook
@@ -11,7 +11,8 @@ class ContextHook(Hook):
         name: str, 
         shortname: str, 
         call: Callable[..., Awaitable[Any]], 
-        key: str=None
+        store_key: str,
+        load_key: Optional[str]=None
     ) -> None:
         super().__init__(
             name, 
@@ -20,7 +21,17 @@ class ContextHook(Hook):
             hook_type=HookType.CONTEXT
         )
         
-        self.context_key = key
+        self.store_key = store_key
+        self.load_key = load_key
 
     async def call(self, context: SimpleContext) -> None:
-        context[self.context_key] = await self._call()
\ No newline at end of file
+
+        if self.load_key:
+            context[self.store_key] = await self.call(
+                context[self.load_key]
+            )
+
+        else:
+            context[self.store_key] = await self._call()
+
+        return context
\ No newline at end of file
