@@ -1,5 +1,6 @@
-from typing import Type, Callable, Awaitable, Any, Dict
+from typing import Type, Callable, Awaitable, Any, Dict, Optional
 from hedra.core.graphs.hooks.hook_types.hook_type import HookType
+from hedra.core.graphs.simple_context import SimpleContext
 from .hook import Hook
 from .hook_metadata import HookMetadata
 
@@ -11,6 +12,7 @@ class SetupHook(Hook):
         name: str, 
         shortname: str, 
         call: Callable[..., Awaitable[Any]], 
+        key: Optional[str]=None,
         metadata: Dict[str, Any]={}
     ) -> None:
         super().__init__(
@@ -20,5 +22,14 @@ class SetupHook(Hook):
             hook_type=HookType.SETUP
         )
 
-        self.call: Type[self._call] = self._call
-        self.metadata = HookMetadata(**metadata)
\ No newline at end of file
+        self.key = key
+        self.metadata = HookMetadata(**metadata)
+
+    async def call(self, context: SimpleContext):
+        results = await self._call()
+
+        if self.key:
+            context[self.key] = results
+
+
+        return context
\ No newline at end of file
