@@ -1,5 +1,6 @@
 import json
-from typing import Dict, Any
+from typing import Dict, Any, Tuple, Dict
+from hedra.core.graphs.hooks.hook_types.hook_type import HookType
 from hedra.core.engines.types.http2 import HTTP2Result
 from hedra.core.graphs.stages.base.stage import Stage
 from .base_event import BaseEvent
@@ -23,7 +24,11 @@ class HTTP2Event(BaseEvent):
         'timings'
     )
 
-    def __init__(self, stage: Any, result: HTTP2Result) -> None:
+    def __init__(
+        self, 
+        stage: Any, 
+        result: HTTP2Result
+    ) -> None:
         super(HTTP2Event, self).__init__(
             stage,
             result
